==> owncloud-8.1.0p2.tgz: owncloud/core/l10n/ka_GE.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "კვირა",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "January" : "იანვარი",
    "February" : "თებერვალი",
    "March" : "მარტი",
    "April" : "აპრილი",
    "May" : "მაისი",
    "June" : "ივნისი",
    "July" : "ივლისი",
    "August" : "აგვისტო",
    "September" : "სექტემბერი",
    "October" : "ოქტომბერი",
    "November" : "ნოემბერი",
    "December" : "დეკემბერი",
    "Settings" : "პარამეტრები",
    "Saving..." : "შენახვა...",
    "No" : "არა",
    "Yes" : "კი",
    "Choose" : "არჩევა",
    "Ok" : "დიახ",
    "New Files" : "ახალი ფაილები",
    "Cancel" : "უარყოფა",
    "Shared" : "გაზიარებული",
    "Share" : "გაზიარება",
    "Error" : "შეცდომა",
    "Error while sharing" : "შეცდომა გაზიარების დროს",
    "Error while unsharing" : "შეცდომა გაზიარების გაუქმების დროს",
    "Error while changing permissions" : "შეცდომა დაშვების ცვლილების დროს",
    "Shared with you and the group {group} by {owner}" : "გაზიარდა თქვენთვის და ჯგუფისთვის {group}, {owner}–ის მიერ",
    "Shared with you by {owner}" : "გაზიარდა თქვენთვის {owner}–ის მიერ",
    "Password protect" : "პაროლით დაცვა",
    "Password" : "პაროლი",
    "Email link to person" : "ლინკის პიროვნების იმეილზე გაგზავნა",
    "Send" : "გაგზავნა",
    "Set expiration date" : "მიუთითე ვადის გასვლის დრო",
    "Expiration" : "ვადის გასვლის დრო",
    "Expiration date" : "ვადის გასვლის დრო",
    "group" : "ჯგუფი",
    "Resharing is not allowed" : "მეორეჯერ გაზიარება არ არის დაშვებული",
    "Shared in {item} with {user}" : "გაზიარდა {item}–ში  {user}–ის მიერ",
    "Unshare" : "გაუზიარებადი",
    "can edit" : "შეგიძლია შეცვლა",
    "access control" : "დაშვების კონტროლი",
    "create" : "შექმნა",
    "delete" : "წაშლა",
    "Password protected" : "პაროლით დაცული",
    "Error unsetting expiration date" : "შეცდომა ვადის გასვლის მოხსნის დროს",
    "Error setting expiration date" : "შეცდომა ვადის გასვლის მითითების დროს",
    "Sending ..." : "გაგზავნა ....",
    "Email sent" : "იმეილი გაიგზავნა",
    "Warning" : "გაფრთხილება",
    "The object type is not specified." : "ობიექტის ტიპი არ არის მითითებული.",
    "Delete" : "წაშლა",
    "Add" : "დამატება",
    "The update was successful. Redirecting you to ownCloud now." : "განახლება ვერ განხორციელდა. გადამისამართება თქვენს ownCloud–ზე.",
    "Use the following link to reset your password: {link}" : "გამოიყენე შემდეგი ლინკი პაროლის შესაცვლელად: {link}",
    "New password" : "ახალი პაროლი",
    "Reset password" : "პაროლის შეცვლა",
    "Personal" : "პირადი",
    "Users" : "მომხმარებელი",
    "Apps" : "აპლიკაციები",
    "Admin" : "ადმინისტრატორი",
    "Help" : "დახმარება",
    "Access forbidden" : "წვდომა აკრძალულია",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "თქვენი data დირექტორია და ფაილები დაშვებადია ინტერნეტში რადგან  .htaccess ფაილი არ მუშაობს.",
    "Create an <strong>admin account</strong>" : "შექმენი <strong>ადმინ ექაუნტი</strong>",
    "Username" : "მომხმარებლის სახელი",
    "Data folder" : "მონაცემთა საქაღალდე",
    "Configure the database" : "მონაცემთა ბაზის კონფიგურირება",
    "Database user" : "მონაცემთა ბაზის მომხმარებელი",
    "Database password" : "მონაცემთა ბაზის პაროლი",
    "Database name" : "მონაცემთა ბაზის სახელი",
    "Database tablespace" : "ბაზის ცხრილის ზომა",
    "Database host" : "მონაცემთა ბაზის ჰოსტი",
    "Finish setup" : "კონფიგურაციის დასრულება",
    "Log out" : "გამოსვლა",
    "Search" : "ძებნა",
    "remember" : "დამახსოვრება",
    "Log in" : "შესვლა",
    "Alternative Logins" : "ალტერნატიული Login–ი"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.3.tgz: owncloud/core/l10n/ka_GE.js <==
OC.L10N.register(
    "core",
    {
    "Sunday" : "კვირა",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "Sun." : "კვ.",
    "Mon." : "ორშ.",
    "Tue." : "სამ.",
    "Wed." : "ოთხ.",
    "Thu." : "ხუთ.",
    "Fri." : "პარ.",
    "Sat." : "შაბ.",
    "January" : "იანვარი",
    "February" : "თებერვალი",
    "March" : "მარტი",
    "April" : "აპრილი",
    "May" : "მაისი",
    "June" : "ივნისი",
    "July" : "ივლისი",
    "August" : "აგვისტო",
    "September" : "სექტემბერი",
    "October" : "ოქტომბერი",
    "November" : "ნოემბერი",
    "December" : "დეკემბერი",
    "Jan." : "იან.",
    "Feb." : "თებ.",
    "Mar." : "მარ.",
    "Apr." : "აპრ.",
    "May." : "მაი.",
    "Jun." : "ივნ.",
    "Jul." : "ივლ.",
    "Aug." : "აგვ.",
    "Sep." : "სექ.",
    "Oct." : "ოქტ.",
    "Nov." : "ნოე.",
    "Dec." : "დეკ.",
    "Settings" : "პარამეტრები",
    "Saving..." : "შენახვა...",
    "seconds ago" : "წამის წინ",
    "No" : "არა",
    "Yes" : "კი",
    "Choose" : "არჩევა",
    "Ok" : "დიახ",
    "New Files" : "ახალი ფაილები",
    "Cancel" : "უარყოფა",
    "Shared" : "გაზიარებული",
    "Error" : "შეცდომა",
    "Error while sharing" : "შეცდომა გაზიარების დროს",
    "Error while unsharing" : "შეცდომა გაზიარების გაუქმების დროს",
    "Error setting expiration date" : "შეცდომა ვადის გასვლის მითითების დროს",
    "Set expiration date" : "მიუთითე ვადის გასვლის დრო",
    "Expiration" : "ვადის გასვლის დრო",
    "Expiration date" : "ვადის გასვლის დრო",
    "Sending ..." : "გაგზავნა ....",
    "Email sent" : "იმეილი გაიგზავნა",
    "Resharing is not allowed" : "მეორეჯერ გაზიარება არ არის დაშვებული",
    "Password protect" : "პაროლით დაცვა",
    "Password" : "პაროლი",
    "Email link to person" : "ლინკის პიროვნების იმეილზე გაგზავნა",
    "Send" : "გაგზავნა",
    "Shared with you and the group {group} by {owner}" : "გაზიარდა თქვენთვის და ჯგუფისთვის {group}, {owner}–ის მიერ",
    "Shared with you by {owner}" : "გაზიარდა თქვენთვის {owner}–ის მიერ",
    "group" : "ჯგუფი",
    "Unshare" : "გაუზიარებადი",
    "can edit" : "შეგიძლია შეცვლა",
    "create" : "შექმნა",
    "delete" : "წაშლა",
    "access control" : "დაშვების კონტროლი",
    "Share" : "გაზიარება",
    "Warning" : "გაფრთხილება",
    "Delete" : "წაშლა",
    "Rename" : "გადარქმევა",
    "The object type is not specified." : "ობიექტის ტიპი არ არის მითითებული.",
    "Add" : "დამატება",
    "The update was successful. Redirecting you to ownCloud now." : "განახლება ვერ განხორციელდა. გადამისამართება თქვენს ownCloud–ზე.",
    "Personal" : "პირადი",
    "Users" : "მომხმარებელი",
    "Apps" : "აპლიკაციები",
    "Admin" : "ადმინისტრატორი",
    "Help" : "დახმარება",
    "Access forbidden" : "წვდომა აკრძალულია",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "თქვენი data დირექტორია და ფაილები დაშვებადია ინტერნეტში რადგან  .htaccess ფაილი არ მუშაობს.",
    "Create an <strong>admin account</strong>" : "შექმენი <strong>ადმინ ექაუნტი</strong>",
    "Username" : "მომხმარებლის სახელი",
    "Data folder" : "მონაცემთა საქაღალდე",
    "Configure the database" : "მონაცემთა ბაზის კონფიგურირება",
    "Database user" : "მონაცემთა ბაზის მომხმარებელი",
    "Database password" : "მონაცემთა ბაზის პაროლი",
    "Database name" : "მონაცემთა ბაზის სახელი",
    "Database tablespace" : "ბაზის ცხრილის ზომა",
    "Database host" : "მონაცემთა ბაზის ჰოსტი",
    "Finish setup" : "კონფიგურაციის დასრულება",
    "Log out" : "გამოსვლა",
    "Search" : "ძებნა",
    "Log in" : "შესვლა",
    "Alternative Logins" : "ალტერნატიული Login–ი",
    "Use the following link to reset your password: {link}" : "გამოიყენე შემდეგი ლინკი პაროლის შესაცვლელად: {link}",
    "New password" : "ახალი პაროლი",
    "Reset password" : "პაროლის შეცვლა"
},
"nplurals=1; plural=0;");
